@@ -14,11 +14,13 @@ def Open(filename):
     if os.path.isfile(filename):
         with open(filename) as Zype:
             content = Zype.read()
-        content = '{\n' + content
-        content = content + '\n}'
         content = content.replace('<', '  "')
         content = content.replace('>', '":')
         content = content.replace(';', ',')
+        content = content.replace('{', '{')
+        content = content.replace('}', '  }')
+        content = content.replace("'", '"')
+        content = '{\n' + content + '\n}'
         content = content.replace('(', '{')
         content = content.replace(')', '  }')
         return json.loads(content)
